"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LambdaResponseBuilder = void 0;
const declare_1 = require("./declare");
const headers_1 = require("./headers");
class LambdaResponseBuilder {
    static create() {
        return new LambdaResponseBuilder();
    }
    constructor() {
        this._headers = {};
        this._body = {};
        this._isBase64Encoded = false;
    }
    addHeader(key, value) {
        this._headers[key] = value;
        return this;
    }
    mergeHeaders(headers) {
        this._headers = {
            ...this._headers,
            ...headers,
        };
        return this;
    }
    replaceHeaders(headers) {
        this._headers = headers;
        return this;
    }
    addBody(key, value) {
        if (typeof this._body === 'string') {
            this._body += String(value);
            return this;
        }
        if (typeof this._body === 'number') {
            this._body += Number(value);
            return this;
        }
        if (typeof this._body === 'boolean') {
            this._body = Boolean(value);
            return this;
        }
        this._body[key] = value;
        return this;
    }
    replaceBody(body) {
        this._body = body;
        return this;
    }
    setBase64Encoded(isBase64Encoded) {
        this._isBase64Encoded = isBase64Encoded;
        return this;
    }
    build(statusCode) {
        const constructedHeaders = (0, headers_1.createConstructHeaders)(this._headers);
        if (typeof this._body === 'string'
            && typeof this._body === 'number'
            && typeof this._body === 'boolean') {
            return {
                statusCode,
                body: (0, declare_1.fixUndefinedStringifyBody)({
                    message: this._body,
                }),
                headers: constructedHeaders.headers,
                multiValueHeaders: constructedHeaders.multiValueHeaders,
                isBase64Encoded: this._isBase64Encoded,
            };
        }
        return {
            statusCode,
            body: (0, declare_1.fixUndefinedStringifyBody)(this._body),
            headers: constructedHeaders.headers,
            multiValueHeaders: constructedHeaders.multiValueHeaders,
            isBase64Encoded: this._isBase64Encoded,
        };
    }
}
exports.LambdaResponseBuilder = LambdaResponseBuilder;
